==> 0.0.1.zip: jury_site/application/views/header.php <==
<!DOCTYPE html>
<html>
<head>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <!-- The above 3 meta tags *must* come first in the head; any other head content must come *after* these tags -->
    <title>Score systeem</title>

    <!-- Bootstrap -->
    <link href="<?php echo base_url('bootstrap/css/bootstrap.min.css'); ?>" rel="stylesheet">

    <!-- HTML5 shim and Respond.js for IE8 support of HTML5 elements and media queries -->
    <!-- WARNING: Respond.js doesn't work if you view the page via file:// -->
    <!--[if lt IE 9]>
      <script src="https://oss.maxcdn.com/html5shiv/3.7.2/html5shiv.min.js"></script>
      <script src="https://oss.maxcdn.com/respond/1.4.2/respond.min.js"></script>
    <![endif]-->
</head>
<body>

<?php if($this->session->userdata('validated')) { ?>
<div class="container">
	<div class="header clearfix">
		<nav>
			<ul class="nav nav-pills pull-right">
				<li role="presentation" <?php if ($page == 'home') {?> class="active" <?php } ?> ><a href="<?php echo base_url('/');?>">Home</a></li>
				<li role="presentation" <?php if ($page == 'beoordelen') {?> class="active" <?php } ?> ><a href="<?php echo base_url('beoordelen/');?>">Beoordelen</a></li>
				<?php if ($this->session->admin == '1' OR $this->session->superadmin == '1') { ?>
				<li role="presentation" <?php if ($page == 'configuratie') {?> class="active" <?php } ?> ><a href="<?php echo base_url('admin/config/');?>">Configuratie</a></li>
				<?php }; ?>
				<li role="presentation" <?php if ($page == 'info') {?> class="active" <?php } ?> ><a href="<?php echo base_url('info/');?>">Informatie</a></li>
				<?php if ($this->session->superadmin == '1') { ?>
					<li role="presentation" <?php if ($page == 'info') {?> class="active" <?php } ?> ><a href="<?php echo base_url('admin/regio/');?>">Regio </a></li>
				<?php }; ?>
				<li role="presentation"><a href="<?php echo base_url('logout/');?>">Logout</a></li>
			</ul>
		</nav>
	</div>
</div>
<?php } ?>

==> 0.0.2.zip: jury_site/application/views/header.php <==
<!DOCTYPE html>
<html>
<head>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <!-- The above 3 meta tags *must* come first in the head; any other head content must come *after* these tags -->
    <title>Score systeem</title>

    <!-- Bootstrap -->
    <link href="<?php echo base_url('bootstrap/css/bootstrap.min.css'); ?>" rel="stylesheet">

    <!-- HTML5 shim and Respond.js for IE8 support of HTML5 elements and media queries -->
    <!-- WARNING: Respond.js doesn't work if you view the page via file:// -->
    <!--[if lt IE 9]>
      <script src="https://oss.maxcdn.com/html5shiv/3.7.2/html5shiv.min.js"></script>
      <script src="https://oss.maxcdn.com/respond/1.4.2/respond.min.js"></script>
    <![endif]-->
</head>
<body>

<?php if($this->session->userdata('validated')) { ?>
<div class="container">
	<div class="header clearfix">
		<nav>
			<div class="navbar-text"><?php echo $this->session->regionaam; ?></div>
			<ul class="nav nav-pills pull-right">
				<li role="presentation" <?php if ($page == 'home') {?> class="active" <?php } ?> ><a href="<?php echo base_url('/');?>">Home</a></li>
				<li role="presentation" <?php if ($page == 'beoordelen') {?> class="active" <?php } ?> ><a href="<?php echo base_url('beoordelen/');?>">Beoordelen</a></li>
				<?php if ($this->session->admin == '1' OR $this->session->superadmin == '1') { ?>
				<li role="presentation" <?php if ($page == 'config') {?> class="active" <?php } ?> ><a href="<?php echo base_url('config/');?>">Configuratie</a></li>
				<?php }; ?>
				<li role="presentation" <?php if ($page == 'info') {?> class="active" <?php } ?> ><a href="<?php echo base_url('info/');?>">Informatie</a></li>
				<?php if ($this->session->superadmin == '1') { ?>
					<li role="presentation" <?php if ($page == 'regio') {?> class="active" <?php } ?> ><a href="<?php echo base_url('dashboard/changeregio/');?>">Regio </a></li>
				<?php }; ?>
				<li role="presentation"><a href="<?php echo base_url('logout/');?>">Logout</a></li>
			</ul>
		</nav>
	</div>
</div>
<?php } ?>
